@@ -1,5 +1,5 @@
 package Playwright::Util;
-$Playwright::Util::VERSION = '1.251';
+$Playwright::Util::VERSION = '1.291';
 use strict;
 use warnings;
 
@@ -17,8 +17,8 @@ use POSIX();
 no warnings 'experimental';
 use feature qw{signatures};
 
-sub request ( $method, $url, $port, $ua, %args ) {
-    my $fullurl = "http://localhost:$port/$url";
+sub request ( $method, $url, $host, $port, $ua, %args ) {
+    my $fullurl = "http://$host:$port/$url";
 
     # Handle passing Playwright elements as arguments
     if ( ref $args{args} eq 'ARRAY' ) {
@@ -92,9 +92,9 @@ Playwright::Util - Common utility functions for the Playwright module
 
 =head1 VERSION
 
-version 1.251
+version 1.291
 
-=head2 request(STRING method, STRING url, INTEGER port, LWP::UserAgent ua, HASH args) = HASH
+=head2 request(STRING method, STRING url, STRING host, INTEGER port, LWP::UserAgent ua, HASH args) = HASH
 
 De-duplicates request logic in the Playwright Modules.
 
